@@ -31,21 +31,21 @@ import javax.security.auth.x500.X500Principal;
 
 import org.bouncycastle.asn1.ASN1InputStream;
 import org.bouncycastle.asn1.ASN1OctetString;
+import org.bouncycastle.asn1.ASN1Primitive;
 import org.bouncycastle.asn1.ASN1Sequence;
 import org.bouncycastle.asn1.ASN1TaggedObject;
 import org.bouncycastle.asn1.DERIA5String;
-import org.bouncycastle.asn1.DERObject;
 import org.bouncycastle.asn1.DEROctetString;
-import org.bouncycastle.asn1.DERSequence;
+import org.bouncycastle.asn1.DLSequence;
 import org.bouncycastle.asn1.x509.Attribute;
 import org.bouncycastle.asn1.x509.AttributeCertificate;
+import org.bouncycastle.asn1.x509.Certificate;
+import org.bouncycastle.asn1.x509.Extension;
 import org.bouncycastle.asn1.x509.GeneralName;
 import org.bouncycastle.asn1.x509.IetfAttrSyntax;
 import org.bouncycastle.asn1.x509.Target;
 import org.bouncycastle.asn1.x509.TargetInformation;
 import org.bouncycastle.asn1.x509.Targets;
-import org.bouncycastle.asn1.x509.X509CertificateStructure;
-import org.bouncycastle.asn1.x509.X509Extension;
 import org.bouncycastle.cert.X509AttributeCertificateHolder;
 import org.bouncycastle.jce.provider.BouncyCastleProvider;
 import org.bouncycastle.jce.provider.X509CertificateObject;
@@ -83,9 +83,11 @@ public class VOMSACUtils implements VOMSConstants {
    * extension
    * 
    * @param vomsExtension
-   * @return the possybly empty {@link List} of {@link AttributeCertificate}
+   *          the VOMS extension
+   * @return the possibly empty {@link List} of {@link AttributeCertificate}
    *         extracted from a given extension
    * @throws IOException
+   *           in case of deserialization errors
    */
   public static List<AttributeCertificate> getACsFromVOMSExtension(
     byte[] vomsExtension) throws IOException {
@@ -124,8 +126,8 @@ public class VOMSACUtils implements VOMSConstants {
 
       while (theACs.hasMoreElements()) {
 
-        AttributeCertificate parsedAC = new AttributeCertificate(
-          theACs.nextElement());
+        AttributeCertificate parsedAC = 
+          AttributeCertificate.getInstance(theACs.nextElement());
         acs.add(parsedAC);
       }
     }
@@ -142,6 +144,7 @@ public class VOMSACUtils implements VOMSConstants {
    * @return the possibly empty {@link List} of {@link AttributeCertificate}
    *         objects extracted from the VOMS extension
    * @throws IOException
+   *           in case of deserialization errors
    */
   public static List<AttributeCertificate> getACsFromCertificate(
     X509Certificate cert) throws IOException {
@@ -178,8 +181,7 @@ public class VOMSACUtils implements VOMSConstants {
 
     List<String> targets = new ArrayList<String>();
 
-    X509Extension targetExtension = ac
-      .getExtension(X509Extension.targetInformation);
+    Extension targetExtension = ac.getExtension(Extension.targetInformation);
 
     if (targetExtension == null)
       return targets;
@@ -193,7 +195,8 @@ public class VOMSACUtils implements VOMSConstants {
     // The deserialization has to be done by hand since it seems VOMS
     // does not correctly encode the ACTargets extension...
     ASN1Sequence targetSequence = (ASN1Sequence) asn1TargetContainer
-      .getDERObject();
+      .toASN1Primitive();
+
     Target[] asn1Targets = new Target[targetSequence.size()];
 
     int count = 0;
@@ -291,9 +294,11 @@ public class VOMSACUtils implements VOMSConstants {
     Attribute[] asn1Attrs = acHolder.getAttributes(VOMS_FQANS_OID);
 
     for (Attribute a : asn1Attrs) {
-      DERObject theVOMSDerObject = a.getAttributeValues()[0].getDERObject();
-      IetfAttrSyntax attrSyntax = new IetfAttrSyntax(
-        ASN1Sequence.getInstance(theVOMSDerObject));
+      ASN1Primitive theVOMSDerObject = a.getAttributeValues()[0]
+        .toASN1Primitive();
+
+      IetfAttrSyntax attrSyntax = IetfAttrSyntax.getInstance(ASN1Sequence
+        .getInstance(theVOMSDerObject));
 
       String policyAuthority = policyAuthoritySanityChecks(attrSyntax);
 
@@ -350,7 +355,7 @@ public class VOMSACUtils implements VOMSConstants {
 
     List<VOMSGenericAttribute> gas = new ArrayList<VOMSGenericAttribute>();
 
-    X509Extension gasExtension = ac.getExtension(VOMS_GENERIC_ATTRS_OID);
+    Extension gasExtension = ac.getExtension(VOMS_GENERIC_ATTRS_OID);
 
     if (gasExtension == null)
       return gas;
@@ -416,7 +421,7 @@ public class VOMSACUtils implements VOMSConstants {
 
     List<X509Certificate> certs = new ArrayList<X509Certificate>();
 
-    X509Extension e = ac.getExtension(VOMS_CERTS_OID);
+    Extension e = ac.getExtension(VOMS_CERTS_OID);
 
     if (e == null)
       return null;
@@ -429,7 +434,7 @@ public class VOMSACUtils implements VOMSConstants {
     certSeq = (ASN1Sequence) certSeq.getObjectAt(0);
 
     @SuppressWarnings("unchecked")
-    Enumeration<DERSequence> encodedCerts = certSeq.getObjects();
+    Enumeration<DLSequence> encodedCerts = certSeq.getObjects();
 
     CertificateFactory cf = null;
 
@@ -443,7 +448,7 @@ public class VOMSACUtils implements VOMSConstants {
 
     while (encodedCerts.hasMoreElements()) {
 
-      DERSequence s = encodedCerts.nextElement();
+      DLSequence s = encodedCerts.nextElement();
       X509CertificateObject certObj = null;
       byte[] certData = null;
       X509Certificate theCert = null;
@@ -451,7 +456,8 @@ public class VOMSACUtils implements VOMSConstants {
       try {
 
         certObj = new X509CertificateObject(
-          X509CertificateStructure.getInstance(ASN1Sequence.getInstance(s)));
+          Certificate.getInstance(ASN1Sequence.getInstance(s)));
+
         certData = certObj.getEncoded();
         theCert = (X509Certificate) cf
           .generateCertificate(new ByteArrayInputStream(certData));
